Changelog
=========


1.0rc1 (2016-08-29)
-------------------

- Add registry for templates
  [tomgross]

- Fix i18n translate tests
  [tomgross]


1.0b1 (2016-07-25)
------------------

- Initial release.
  [tomgross]
